# tlogg
A fast, advanced [TUI](https://en.wikipedia.org/wiki/Text-based_user_interface) log explorer inspired by [glogg - the fast, smart log explorer](https://github.com/nickbnf/glogg)

[![screenshot](https://raw.githubusercontent.com/ceccopierangiolieugenio/binaryRepo/master/tlogg/screenshot.001.png
)](https://pypi.org/project/tlogg)

# Install
```bash
pip install tlogg
```
# QuickRun
```bash
 $ tlogg -h
usage: tlogg [-h] [-c C] filename [filename ...]

positional arguments:
  filename    the filename/s

optional arguments:
  -h, --help  show this help message and exit
  -c C        config folder (default: "/home/user/.config/tlogg")
```

# Test
### Clone
```bash
git clone https://github.com/ceccopierangiolieugenio/tlogg.git
cd tlogg
```
### Run
```
python3 -m tlogg  <File/s>
```

